@@ -307,15 +307,6 @@ type_names['uint32_t'] = TYPE_UINT32
 type_names['int64_t'] = TYPE_INT64
 type_names['uint64_t'] = TYPE_UINT64
 
-type_names['__int8_t'] = TYPE_INT8
-type_names['__uint8_t'] = TYPE_UINT8
-type_names['__int16_t'] = TYPE_INT16
-type_names['__uint16_t'] = TYPE_UINT16
-type_names['__int32_t'] = TYPE_INT32
-type_names['__uint32_t'] = TYPE_UINT32
-type_names['__int64_t'] = TYPE_INT64
-type_names['__uint64_t'] = TYPE_UINT64
-
 # A few additional GLib type aliases
 type_names['guchar'] = TYPE_UINT8
 type_names['gchararray'] = TYPE_STRING
@@ -353,6 +344,8 @@ type_names['FILE*'] = TYPE_ANY
 # integers it's easy enough to expand them.
 type_names['size_t'] = type_names['gsize']
 type_names['ssize_t'] = type_names['gssize']
+type_names['uintptr_t'] = type_names['guintptr']
+type_names['intptr_t'] = type_names['gintptr']
 type_names['time_t'] = TYPE_LONG
 type_names['off_t'] = type_names['gsize']
 type_names['pid_t'] = TYPE_INT
@@ -372,6 +365,7 @@ PARAM_DIRECTION_INOUT = 'inout'
 PARAM_SCOPE_CALL = 'call'
 PARAM_SCOPE_ASYNC = 'async'
 PARAM_SCOPE_NOTIFIED = 'notified'
+PARAM_SCOPE_FOREVER = 'forever'
 
 PARAM_TRANSFER_NONE = 'none'
 PARAM_TRANSFER_CONTAINER = 'container'
@@ -1190,6 +1184,7 @@ class Signal(Callable):
         self.detailed = detailed
         self.action = action
         self.no_hooks = no_hooks
+        self.emitter = None
 
 
 class Class(Node, Registered):
